@@ -8,6 +8,7 @@ import requests
 import openpyxl
 import threading
 from gevent import pywsgi
+from dynaconf import settings
 
 """
 使用方法如下：
@@ -23,7 +24,7 @@ from gevent import pywsgi
                 restart_flag, args],
                 实例：
                 ['event_verifier', '/var/log/utilization_producer/log/timing_utilization_producer.info.log.',
-                'l', 'm', '3', 0, 1],
+                'l', 'm', 3, 0, 1],
                 ]
     
     service_name: 如果监控日志，则是重启服务时的服务名；如果是接口测试，则是url
@@ -42,18 +43,28 @@ TIMEZONE = 'Asia/Shanghai'
 
 class Monitor:
 
-    def __init__(self, scheduler_list: dict):
+    def __init__(self, scheduler_list=None, port=5000):
         # 初始化输入参数
-        self.service_list = self.scheduler_init(scheduler_list)
+        self.scheduler_list = scheduler_list
+        self.service_list = self.scheduler_init()
         # 初始化本地文件储存相应信息
         self.create_local_excel()
 
         self.time = datetime.now().strftime("%Y-%m-%d")
         self.hour = datetime.now().hour
 
-    def run(self, logs_path='/var/log/event/control_log/', host='0.0.0.0', port=5000):
+        self.port = settings.get('MONITOR_PORT', port)
+
+    def run(self, logs_path='/var/log/event/control_log/', host='0.0.0.0'):
         log_init('health_monitor', debug=False, log_path=logs_path)
         try:
+            if isinstance(self.port, str):
+                port = eval(self.port)
+            elif isinstance(self.port, int):
+                port = self.port
+            else:
+                log.info('健康检测端口配置有误，默认使用5000')
+                port = 5000
 
             t1 = threading.Thread(target=self.start_scheduler)
             t2 = threading.Thread(target=self.api_run, args=[host, port])
@@ -202,9 +213,18 @@ class Monitor:
                 log.info(f"{service.name}服务监控类型不存在，服务监控类型目前仅支持l,a两种")
         scheduler.start()
 
-    @staticmethod
-    def scheduler_init(scheduler_list):
-        return [Service(_) for _ in scheduler_list]
+    def scheduler_init(self):
+        if not self.scheduler_list:
+            return [Service(_) for _ in self.scheduler_list]
+        else:
+            config_scheduler_list = settings.get('MONITOR_SCHEDULERS')
+            res = []
+            for _ in config_scheduler_list:
+                if isinstance(_, list) or isinstance(_, dict):
+                    res.append(Service(_))
+                else:
+                    log.info(f'{_}的配置类型不是list或dict，请检查')
+            return res
 
 
 class ServiceHealthApi(MethodView):
@@ -232,101 +252,27 @@ class ServiceHealthApi(MethodView):
 class Service:
 
     def __init__(self, msg):
-        self.name = msg[0]
-        self.log_path = msg[1]
-        self.monitor_type = msg[2]
-        self.scheduler_period_type = msg[3]
-        self.scheduler_period = msg[4]
-        self.dingtalk_function = msg[5]
-        self.restart_flag = msg[6]
-        if len(msg) == 8:
-            self.restart_name = msg[7]
-        elif len(msg) < 8:
-            self.restart_name = 0
-        if len(msg) == 9:
-            self.args = msg[8] if msg[8] else None
-
-
-if __name__ == '__main__':
-    # app = Flask(__name__)
-    #
-    # @app.route('/api/ai/service_monitor', methods=['GET'])
-    # def get_service_health():
-        # record_path = request.args.get('record_path')
-        # wb = openpyxl.load_workbook(record_path)
-        # ws = wb.active
-        # error_times = ws['A1'].value
-        # wb.close()
-
-    #     error_times = 1
-    #
-    #     if error_times < 3:
-    #         response = {'msg': '服务正常', 'code': 200,
-    #                     'data': error_times}
-    #         return jsonify(response)
-    #     else:
-    #         msg = {'msg': '服务异常'}
-    #         # 构建一个response
-    #         response = make_response(json.dumps(msg), 400)
-    #         return response
-    #
-    # app.config['env'] = 'development'
-    # app.run(host='0.0.0.0', port=5001)
-
-    # wb = openpyxl.Workbook()
-    # ws = wb.active
-    # ws['A1'] = 1000  # 储存监控日志大小
-    # ws['B1'] = 0  # 储存check_times
-    # ws['C1'] = 0  # 储存error_times
-    # wb.save(f'test_monitor.xlsx')
-    # wb.close()
-
-    # from intelab_python_tool.tools.log import log, log_init
-    # log_init('./')
-    # wb = openpyxl.load_workbook('test_monitor.xlsx')
-    # ws = wb.active
-    # old_data_bytes = ws['A1'].value
-    # check_times = ws['B1'].value
-    # error_times = ws['C1'].value
-    # log.info(type(old_data_bytes))
-    # a = 2
-    # log.info(type(a))
-    # log.info(f'{old_data_bytes}, {check_times}, {error_times}')
-    #
-    #
-    # ws['A1'].value = 900
-    #
-    # wb.save('test_monitor.xlsx')
-
-    # a = Service([1,1,1,1,1,1,1])
-    # s = a.name if not a.restart_name else a.restart_name
-    # print(s)
-
-    app = Flask(__name__)
-
-
-    @app.route('/api/ai/service_monitor', methods=['GET'])
-    def get_service_health(record_paths):
-        record_path_list = eval(record_paths)
-        path_fix = '/Users/ouyangyi/ilabservice/'
-        error_time_list = []
-        for _ in record_path_list:
-            record_path = path_fix + _ + '_monitor.xlsx'
-            wb = openpyxl.load_workbook(record_path)
-            ws = wb.actice
-            error_times = ws['C1']
-            error_time_list.append(error_times)
-            wb.close()
-
-        if max(error_time_list) < 3:
-            response = {'msg': '服务正常', 'code': 200,
-                        'data': error_time_list}
-            return jsonify(response)
-        else:
-            msg = {'msg': '服务异常'}
-            response = make_response(json.dumps(msg), 400)
-            return response
-
-    app.config['env'] = 'development'
-    app.run(host='0.0.0.0', port=5001)
-
+        if isinstance(msg, list):
+            self.name = msg[0]
+            self.log_path = msg[1]
+            self.monitor_type = msg[2]
+            self.scheduler_period_type = msg[3]
+            self.scheduler_period = msg[4]
+            self.dingtalk_function = msg[5]
+            self.restart_flag = msg[6]
+            if len(msg) == 8:
+                self.restart_name = msg[7]
+            elif len(msg) < 8:
+                self.restart_name = 0
+            if len(msg) == 9:
+                self.args = msg[8] if msg[8] else None
+        elif isinstance(msg, dict):
+            self.name = msg['service_name']
+            self.log_path = msg['log_path']
+            self.monitor_type = msg['monitor_type']
+            self.scheduler_period_type = msg['scheduler_period_type']
+            self.scheduler_period = msg['scheduler_period']
+            self.dingtalk_function = msg['ding_talk_function']
+            self.restart_flag = msg['restart_flag']
+            self.restart_name = msg['restart_name']
+            self.args = msg['args']
